pub struct Signature(/* private fields */);Expand description
Ethereum signed-message signature: R || S || V with V
normalized to {27, 28} on the wire, matching bee-js.
Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn recover_public_key(&self, data: &[u8]) -> Result<PublicKey, Error>
pub fn recover_public_key(&self, data: &[u8]) -> Result<PublicKey, Error>
Recover the public key that produced this signature for data,
using the Ethereum signed-message scheme.
Sourcepub fn is_valid(&self, data: &[u8], expected: EthAddress) -> bool
pub fn is_valid(&self, data: &[u8], expected: EthAddress) -> bool
True iff the signature is valid against data and the recovered
signer matches expected.